@@ -1,13 +1,13 @@
 package Sah::Schema::perl::modargs;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = ['perl::modname_with_optional_args' => {
     summary => 'Shorter alias for perl::modname_with_optional_args',
-}, {}];
+}];
 
 1;
 # ABSTRACT: Shorter alias for perl::modname_with_optional_args
@@ -24,7 +24,7 @@ Sah::Schema::perl::modargs - Shorter alias for perl::modname_with_optional_args
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::modargs (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::modargs (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -54,7 +54,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -74,7 +75,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
