@@ -1,9 +1,9 @@
 package Sah::Schema::perl::modname::not_installed;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = ['perl::modname' => {
     summary => 'Name of a Perl module that is not installed locally',
@@ -23,7 +23,7 @@ _
     examples => [
     ],
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Name of a Perl module that is not installed locally
@@ -40,7 +40,7 @@ Sah::Schema::perl::modname::not_installed - Name of a Perl module that is not in
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::modname::not_installed (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::modname::not_installed (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -70,7 +70,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -90,7 +91,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
