@@ -1,9 +1,9 @@
 package Sah::Schema::perl::modname_or_prefix;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module name (e.g. Foo::Bar) or prefix (e.g. Foo::Bar::)',
@@ -36,7 +36,7 @@ _
         {value=>'Foo|Bar', valid=>0},
     ],
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Perl module name (e.g. Foo::Bar) or prefix (e.g. Foo::Bar::)
@@ -53,7 +53,7 @@ Sah::Schema::perl::modname_or_prefix - Perl module name (e.g. Foo::Bar) or prefi
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::modname_or_prefix (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::modname_or_prefix (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -83,7 +83,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -103,7 +104,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
