@@ -1,9 +1,9 @@
 package Sah::Schema::perl::modname_with_ver;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module name with version number suffix, e.g. Foo::Bar@0.001',
@@ -26,7 +26,7 @@ our $schema = [str => {
         {value=>'Foo::Bar@a', valid=>0},
     ],
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Perl module name with version number suffix, e.g. Foo::Bar@0.001
@@ -43,7 +43,7 @@ Sah::Schema::perl::modname_with_ver - Perl module name with version number suffi
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::modname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::modname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -73,7 +73,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -93,7 +94,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
