@@ -1,9 +1,9 @@
 package Sah::Schema::perl::modnames;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = [array => {
     summary => 'Array of Perl module names, e.g. ["Foo::Bar", "Baz"]',
@@ -33,7 +33,7 @@ _
     # provide a default completion which is from list of installed perl modules
     'x.element_completion' => 'perl_modname',
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Array of Perl module names, e.g. ["Foo::Bar", "Baz"]
@@ -50,7 +50,7 @@ Sah::Schema::perl::modnames - Array of Perl module names, e.g. ["Foo::Bar", "Baz
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::modnames (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::modnames (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -80,7 +80,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -100,7 +101,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
