@@ -1,9 +1,9 @@
 package Sah::Schema::perl::modprefix;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module prefix, e.g. Foo::Bar::',
@@ -44,7 +44,7 @@ _
         {value=>'Foo-', valid=>1, validated_value=>'Foo::'},
     ],
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Perl module prefix, e.g. Foo::Bar::
@@ -61,7 +61,7 @@ Sah::Schema::perl::modprefix - Perl module prefix, e.g. Foo::Bar::
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -91,7 +91,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -111,7 +112,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
