@@ -1,9 +1,9 @@
 package Sah::Schema::perl::pod_filename;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = [str => {
     summary => 'A .pod filename, e.g. /path/Foo.pod',
@@ -57,7 +57,7 @@ _
         Complete::Util::combine_answers(@answers);
     },
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: A .pod filename, e.g. /path/Foo.pod
@@ -74,7 +74,7 @@ Sah::Schema::perl::pod_filename - A .pod filename, e.g. /path/Foo.pod
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::pod_filename (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::pod_filename (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -124,7 +125,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
