@@ -1,9 +1,9 @@
 package Sah::Schema::perl::unqualified_funcname;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl function name which must not be qualified with a package name, e.g. subname',
@@ -25,7 +25,7 @@ _
     # TODO: provide convenience by providing list of core function names etc
     #'x.completion' => 'perl_funcname',
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Perl function name which must not be qualified with a package name, e.g. subname
@@ -42,7 +42,7 @@ Sah::Schema::perl::unqualified_funcname - Perl function name which must not be q
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::unqualified_funcname (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::unqualified_funcname (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -72,7 +72,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -92,7 +93,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
