@@ -1,9 +1,9 @@
 package Sah::Schema::perl::version;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 our $schema = [obj => {
     summary => 'Perl version object',
@@ -17,7 +17,7 @@ _
     'x.perl.coerce_rules' => [
         'From_str::perl_version',
     ],
-}, {}];
+}];
 
 1;
 # ABSTRACT: Perl version object
@@ -34,7 +34,7 @@ Sah::Schema::perl::version - Perl version object
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schema::perl::version (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schema::perl::version (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,8 @@ To specify schema in L<Rinci> function metadata and use the metadata with
 L<Perinci::CmdLine> to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -84,7 +85,8 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
  Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
 
