@@ -1,7 +1,7 @@
 package Sah::Schemas::Perl;
 
-our $DATE = '2021-07-19'; # DATE
-our $VERSION = '0.037'; # VERSION
+our $DATE = '2021-07-20'; # DATE
+our $VERSION = '0.038'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas related to Perl
@@ -18,7 +18,7 @@ Sah::Schemas::Perl - Sah schemas related to Perl
 
 =head1 VERSION
 
-This document describes version 0.037 of Sah::Schemas::Perl (from Perl distribution Sah-Schemas-Perl), released on 2021-07-19.
+This document describes version 0.038 of Sah::Schemas::Perl (from Perl distribution Sah-Schemas-Perl), released on 2021-07-20.
 
 =head1 SAH SCHEMAS
 
@@ -128,6 +128,15 @@ offers completion from list of locally installed Perl modules. Second, it
 contains coercion rule so you can also input C<Foo-Bar>, C<Foo/Bar>, C<Foo/Bar.pm>
 or even 'Foo.Bar' and it will be normalized into C<Foo::Bar>.
 
+To see this schema in action on the CLI, you can try e.g. the C<pmless> script
+from L<App::PMUtils> and activate its tab completion (see its manpage for more
+details). Then on the CLI try typing:
+
+ % pmless M/<tab>
+ % pmless dzp/<tab>
+ % pmless Module/List/Wildcard
+ % pmless Module::List::Wildcard
+
 Note that this schema does not check that the Perl module exists or is installed
 locally. To check that, use the C<perl::modname::installed> schema. And there's
 also a C<perl::modname::not_installed> schema.
